@@ -90,7 +90,7 @@ static inline const char *desc46_get_teletexttype_txt(uint8_t i_type)
            i_type == 0x02 ? "Teletext subtitle page" :
            i_type == 0x03 ? "Additional information page" :
            i_type == 0x04 ? "Programme schedule page" :
-           i_type == 0x05 ? "Teletext subtitle page for hearing impaired people schedule page" : "Reserved";
+           i_type == 0x05 ? "Teletext subtitle page for hearing impaired people" : "Reserved";
 }
 
 static inline void desc46n_set_teletextmagazine(uint8_t *p_desc_n,
@@ -131,7 +131,7 @@ static inline void desc46_print(uint8_t *p_desc, f_print pf_print,
         switch (i_print_type) {
         case PRINT_XML:
             pf_print(opaque,
-                 "<%s language=\"%3.3s\" type=\"0x%hhx\" type_txt=\"%s\" mag=\"%hhu\" page=\"0x%hhux\"/>",
+                 "<%s language=\"%3.3s\" type=\"0x%hhx\" type_txt=\"%s\" mag=\"%hhu\" page=\"0x%hhx\"/>",
                  desc_get_tag(p_desc) == 0x46 ? "VBI_TELX_DESC" : "TELX_DESC",
                  (const char *)desc46n_get_code(p_desc_n),
                  desc46n_get_teletexttype(p_desc_n),
@@ -141,7 +141,7 @@ static inline void desc46_print(uint8_t *p_desc, f_print pf_print,
             break;
         default:
             pf_print(opaque,
-                 "    - desc %x %s language=%3.3s type=0x%hhx type_txt=\"%s\" mag=%hhu page=0x%hhux",
+                 "    - desc %x %s language=%3.3s type=0x%hhx type_txt=\"%s\" mag=%hhu page=0x%hhx",
                  desc_get_tag(p_desc),
                  desc_get_tag(p_desc) == 0x46 ? "vbi_telx" : "telx",
                  (const char *)desc46n_get_code(p_desc_n),
